@@ -131,9 +131,9 @@ class KonqSidebarHistoryPlugin : public KonqSidebarPlugin
 public:
     KonqSidebarHistoryPlugin(QObject *parent, const QVariantList &args)
         : KonqSidebarPlugin(parent, args) {}
-    virtual ~KonqSidebarHistoryPlugin() {}
+    ~KonqSidebarHistoryPlugin() override {}
 
-    virtual KonqSidebarModule *createModule(QWidget *parent,
+    KonqSidebarModule *createModule(QWidget *parent,
                                             const KConfigGroup &configGroup,
                                             const QString &desktopname,
                                             const QVariant &unused) override
@@ -143,7 +143,7 @@ public:
         return new KonqSidebarHistoryModule(parent, configGroup);
     }
 
-    virtual QList<QAction *> addNewActions(QObject *parent,
+    QList<QAction *> addNewActions(QObject *parent,
                                            const QList<KConfigGroup> &existingModules,
                                            const QVariant &unused) override
     {
@@ -155,7 +155,7 @@ public:
         return QList<QAction *>() << action;
     }
 
-    virtual QString templateNameForNewModule(const QVariant &actionData,
+    QString templateNameForNewModule(const QVariant &actionData,
             const QVariant &unused) const override
     {
         Q_UNUSED(actionData);
@@ -163,7 +163,7 @@ public:
         return QString::fromLatin1("historyplugin%1.desktop");
     }
 
-    virtual bool createNewModule(const QVariant &actionData, KConfigGroup &configGroup,
+    bool createNewModule(const QVariant &actionData, KConfigGroup &configGroup,
                                  QWidget *parentWidget,
                                  const QVariant &unused) override
     {
