@@ -25,7 +25,6 @@
 #include <QClipboard>
 #include <QMenu>
 #include <QDrag>
-#include <QToolButton>
 #include <QIcon>
 #include <QMimeData>
 
@@ -54,7 +53,7 @@ KonqFrameTabs::KonqFrameTabs(QWidget *parent, KonqFrameContainerBase *parentCont
     : KTabWidget(parent),
       m_pPopupMenu(nullptr),
       m_pSubPopupMenuTab(nullptr),
-      m_rightWidget(nullptr), m_leftWidget(nullptr), m_alwaysTabBar(false)
+      m_rightWidget(nullptr), m_leftWidget(nullptr), m_alwaysTabBar(false), m_forceHideTabBar(false)
 {
     // Set an object name so the widget style can identify this widget.
     setObjectName(QStringLiteral("kde_konq_tabwidget"));
@@ -436,7 +435,9 @@ void KonqFrameTabs::slotInitiateDrag(QWidget *w)
 
 void KonqFrameTabs::updateTabBarVisibility()
 {
-    if (m_alwaysTabBar) {
+    if (m_forceHideTabBar) {
+        tabBar()->hide();
+    } else if (m_alwaysTabBar) {
         tabBar()->show();
     } else {
         tabBar()->setVisible(count() > 1);
@@ -452,6 +453,15 @@ void KonqFrameTabs::setAlwaysTabbedMode(bool enable)
     }
 }
 
+void KonqFrameTabs::forceHideTabBar(bool force)
+{
+    if (m_forceHideTabBar != force) {
+        m_forceHideTabBar = force;
+        updateTabBarVisibility();
+    }
+}
+
+
 void KonqFrameTabs::initPopupMenu()
 {
     m_pPopupMenu = new QMenu(this);
@@ -611,7 +621,7 @@ bool KonqFrameTabs::eventFilter(QObject *watched, QEvent *event)
                 (event->type() == QEvent::MouseButtonPress ||
                  event->type() == QEvent::MouseButtonRelease)) {
             QMouseEvent *e = static_cast<QMouseEvent *>(event);
-            if (e->button() == Qt::MidButton) {
+            if (e->button() == Qt::MiddleButton) {
                 if (event->type() == QEvent::MouseButtonRelease) {
                     const int index = bar->tabAt(e->pos());
                     slotCloseRequest(index);
