@@ -26,6 +26,7 @@
 
 #include <QWebEnginePage>
 
+#include <kparts_version.h>
 #include <KParts/ReadOnlyPart>
 #include <QUrl>
 
@@ -43,6 +44,7 @@ class FeaturePermissionBar;
 class KUrlLabel;
 class WebEngineBrowserExtension;
 class WebEngineWallet;
+class KPluginMetaData;
 
 /**
  * A KPart wrapper for the QtWebEngine's browser rendering engine.
@@ -59,7 +61,10 @@ class KWEBENGINEPARTLIB_EXPORT WebEnginePart : public KParts::ReadOnlyPart
     Q_OBJECT
     Q_PROPERTY( bool modified READ isModified )
 public:
-    explicit WebEnginePart(QWidget* parentWidget = nullptr, QObject* parent = nullptr,
+    explicit WebEnginePart(QWidget* parentWidget, QObject* parent,
+#if KPARTS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
+                         const KPluginMetaData& metaData,
+#endif
                          const QByteArray& cachedHistory = QByteArray(),
                          const QStringList& = QStringList());
     ~WebEnginePart() override;
