@@ -22,6 +22,11 @@
 #include "webenginepart_ext.h"
 #include "webenginepart.h"
 
+#include <kparts_version.h>
+#if KPARTS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
+#include <KPluginMetaData>
+#endif
+
 #include <QWidget>
 
 WebEngineFactory::~WebEngineFactory()
@@ -41,7 +46,11 @@ QObject *WebEngineFactory::create(const char* iface, QWidget *parentWidget, QObj
     // history management with any KParts based application.
     QByteArray histData (m_historyBufContainer.value(parentWidget));
     if (!histData.isEmpty()) histData = qUncompress(histData);
+#if KPARTS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
+    WebEnginePart* part = new WebEnginePart(parentWidget, parent, metaData(), histData);
+#else
     WebEnginePart* part = new WebEnginePart(parentWidget, parent, histData);
+#endif
     WebEngineBrowserExtension* ext = qobject_cast<WebEngineBrowserExtension*>(part->browserExtension());
     if (ext) {
         connect(ext, QOverload<QObject *, const QByteArray &>::of(&WebEngineBrowserExtension::saveHistory),
